#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    name='base30-korean',
    version='0.0.2',
    py_modules=['base30_korean'],
    author='Joseph Kim',
    author_email='iz4blue@gmail.com',
    description='crockford base32를 한국어 실정에 맞게 변형한 base30',
    url='https://github.com/iz4blue/base30-korean',
    license='BSD',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        'Natural Language :: Korean',
    ],
)
